use std::path::Path;

use serde::Serialize;

use crate::config::Config;
use crate::error::CustomError;
use crate::intermediate::IItalic;

use super::macros::render;
use super::RenderObject;

#[derive(Debug, Serialize)]
#[serde(tag = "type")]
#[serde(rename = "italic")]
pub(crate) struct RenderItalic {
    children: Vec<RenderObject>,
}

render!(
    RenderItalic,
    IItalic,
    original,
    config,
    output_directory,
    output_file,
    {
        let children = {
            let mut ret = Vec::new();
            for obj in original.children.iter() {
                ret.push(RenderObject::new(
                    config,
                    output_directory,
                    output_file,
                    obj,
                )?);
            }
            ret
        };

        Ok(RenderItalic { children })
    }
);
